import React, { useState } from "react";
import PropTypes from "prop-types";
import Icons from "@components/base/icons";
import styles from "./styles.module.css";

const Search = ({ onSearch, onClose, value }) => {
  const [inputValue, setInputValue] = useState(value);

  const handleCustomClear = () => {
    onClose("");
    setInputValue(""); // Reset the input value
  };

  const handleKeyPress = (e) => {
    if (e.key === "Enter") {
      onSearch(inputValue);
    }
  };

  const handleChange = (e) => {
    setInputValue(e);
  };

  return (
    <div className={styles["search"]}>
      <span className={`${styles["search-icon"]}`}>
        <Icons name="search" size="small" />
      </span>
      <input
        className={styles["search-input"]}
        type="text"
        autoFocus={true}
        value={inputValue}
        onChange={(e) => handleChange(e.target.value)}
        onKeyUp={handleKeyPress}
        placeholder="Discover news, articles and more"
      />
      {inputValue && (
        <span className={`${styles["close-icon"]}`} onClick={handleCustomClear}>
          <Icons name="close" size="small" />
        </span>
      )}
    </div>
  );
};

Search.propTypes = {
  onSearch: PropTypes.func,
  onClose: PropTypes.func,
};

export default Search;
