import fs from "fs/promises";
import path from "path";
import matter from "gray-matter";
import { remark } from "remark";
import html from "remark-html";

export async function getPostById(fileDirectory, slug) {
  const directory = path.join(process.cwd(), fileDirectory);
  const fileNames = await fs.readdir(directory);
  const data = await Promise.all(
    fileNames.map(async (fileName) => {
      const fullPath = path.join(fileDirectory, fileName);
      const fileContents = await fs.readFile(fullPath, "utf8");
      const { data, content } = matter(fileContents);
      const processedContent = remark()
        .use(html)
        .processSync(content)
        .toString();

      return {
        markdown: processedContent,
        ...data,
      };
    })
  );

  return data.filter((e) => e.id == slug)[0];
}

async function getAllPosts(fileDirectory) {
  const directory = path.join(process.cwd(), fileDirectory);
  const fileNames = await fs.readdir(directory);

  const post = await Promise.all(
    fileNames.map(async (fileName) => {
      const id = fileName.replace(/\.md$/, "");
      const fullPath = path.join(fileDirectory, fileName);
      const fileContents = await fs.readFile(fullPath, "utf8");
      const { data } = matter(fileContents);
      return {
        id,
        ...data,
      };
    })
  );
  return post;
}

export async function getPosts(fileDirectory, page) {
  let post = await getAllPosts(fileDirectory, page);
  return getSlicedPost(post, page);
}

function getSlicedPost(post, page) {
  const itemsPerPage = 6;
  // Calculate the start and end indices for the current page
  const startIndex = (page - 1) * itemsPerPage;
  const endIndex = startIndex + itemsPerPage;
  const slicedData = Array.isArray(post)
    ? post.slice(startIndex, endIndex)
    : [];
  const response = { data: slicedData, total: post?.length };

  return response;
}

export async function getPostsBySearch(fileDirectory, page, search) {
  const post = await getAllPosts(fileDirectory);
  const filterBlog = post.filter((e) => {
    return e.title.toLowerCase().includes(search.toLowerCase());
  });
  let pageNo = filterBlog.length > 6 ? page : page == 1 ? 1 : 0;
  const slicedPost = getSlicedPost(filterBlog, pageNo);
  return slicedPost;
}
